/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


//Qt includes
#include <qlayout.h>
#include <qlabel.h>
#include <qvgroupbox.h>
#include <qbutton.h>
#include <qradiobutton.h>
#include <qwhatsthis.h>
#include <qtooltip.h>

//KDE includes
#include <kfile.h>
#include <klocale.h>
#include <kdialogbase.h>
#include <kiconloader.h>
#include <kapplication.h>
#include <kstandarddirs.h>
#include <kdebug.h>

//Project includes
#include "bootAuthenticationOptions.h"
#include "ksystemlogConfig.h"


BootAuthenticationOptions::BootAuthenticationOptions(QWidget *parent) :
	QWidget(parent) 
	{
	
	QVBoxLayout *layout = new QVBoxLayout(this);
	layout->setSpacing(10);
	
	//Boot log file
	QVGroupBox* bootBox=new QVGroupBox(i18n("Boot Log File"), this);
	
	new QLabel(i18n("Boot Log File:"), bootBox);
	bootURLRequester=new KURLRequester(bootBox);
	bootURLRequester->setMode(KFile::File);
	
	QToolTip::add(bootURLRequester, i18n("<qt>Here, you can type or choose the boot log file (example: <i>/var/log/boot.log</i>).</qt>"));
	QWhatsThis::add(bootURLRequester, i18n("<qt>You can type or choose here the boot log file. This file will be analyzed by KSystemLog when you will choose the <b>Boot log</b> menu item. Generally, its name is <i>/var/log/boot.log</i></qt>"));

	connect(bootURLRequester, SIGNAL(textChanged(const QString&)), this, SLOT(onOptionsChanged(const QString&)));
	
	//Authentication log file
	QVGroupBox* authenticationBox=new QVGroupBox(i18n("Authentication Log File"), this);
	
	new QLabel(i18n("Authentication Log File:"), authenticationBox);
	authenticationURLRequester=new KURLRequester(authenticationBox);
	authenticationURLRequester->setMode(KFile::File);

	QToolTip::add(authenticationURLRequester, i18n("<qt>Here, you can type or choose the authentication log file (example: <i>/var/log/auth.log</i>).</qt>"));
	QWhatsThis::add(authenticationURLRequester, i18n("<qt>You can type or choose here the authentication log file. This file will be analyzed by KSystemLog when you will choose the <b>Authentication log</b> menu item. Generally, its name is <i>/var/log/auth.log</i></qt>"));
	
	connect(authenticationURLRequester, SIGNAL(textChanged(const QString&)), this, SLOT(onOptionsChanged(const QString&)));
	
	QSpacerItem* spacer=new QSpacerItem(0, 0, QSizePolicy::Preferred, QSizePolicy::Expanding);

	layout->addWidget(bootBox);
	layout->addWidget(authenticationBox);
	layout->addItem(spacer);
	
	readConfig();
}


void BootAuthenticationOptions::readConfig() {
	QString file=KSystemLogConfig::bootPath();
	bootURLRequester->setURL(file);

	file=KSystemLogConfig::authenticationPath();
	authenticationURLRequester->setURL(file);
}

void BootAuthenticationOptions::saveConfig() {
	kdDebug() << "Save config from Boot Authentication Options" << endl;
	
	KSystemLogConfig::setAuthenticationPath(bootURLRequester->url());

	KSystemLogConfig::setAuthenticationPath(authenticationURLRequester->url());

}

//TODO Please verify that this is OK !
bool BootAuthenticationOptions::isValid() {
	KURL test1(bootURLRequester->url());
	KURL test2(authenticationURLRequester->url());
	
	if (test1.isValid() && test2.isValid())
		return(true);
	else
		return(false);
}


void BootAuthenticationOptions::onOptionsChanged(const QString& /*text*/) {
	emit optionsChanged(true);
}



#include "bootAuthenticationOptions.moc"
